# This file was created automatically by SWIG.
import gridc

from misc import *

from gdi import *

from fonts import *

from windows import *

from clip_dnd import *

from controls import *

from events import *
import wx

def EVT_GRID_CELL_LEFT_CLICK(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_CELL_LEFT_CLICK, fn)

def EVT_GRID_CELL_RIGHT_CLICK(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_CELL_RIGHT_CLICK, fn)

def EVT_GRID_CELL_LEFT_DCLICK(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_CELL_LEFT_DCLICK, fn)

def EVT_GRID_CELL_RIGHT_DCLICK(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_CELL_RIGHT_DCLICK, fn)

def EVT_GRID_LABEL_LEFT_CLICK(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_LABEL_LEFT_CLICK, fn)

def EVT_GRID_LABEL_RIGHT_CLICK(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_LABEL_RIGHT_CLICK, fn)

def EVT_GRID_LABEL_LEFT_DCLICK(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_LABEL_LEFT_DCLICK, fn)

def EVT_GRID_LABEL_RIGHT_DCLICK(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_LABEL_RIGHT_DCLICK, fn)

def EVT_GRID_ROW_SIZE(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_ROW_SIZE, fn)

def EVT_GRID_COL_SIZE(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_COL_SIZE, fn)

def EVT_GRID_RANGE_SELECT(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_RANGE_SELECT, fn)

def EVT_GRID_CELL_CHANGE(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_CELL_CHANGE, fn)

def EVT_GRID_SELECT_CELL(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_SELECT_CELL, fn)

def EVT_GRID_EDITOR_SHOWN(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_EDITOR_SHOWN, fn)

def EVT_GRID_EDITOR_HIDDEN(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_EDITOR_HIDDEN, fn)

def EVT_GRID_EDITOR_CREATED(win, fn):
    win.Connect(-1, -1, wxEVT_GRID_EDITOR_CREATED, fn)


class wxGridCellRendererPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setOORInfo(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellRenderer__setOORInfo,(self,) + _args, _kwargs)
        return val
    def SetParameters(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellRenderer_SetParameters,(self,) + _args, _kwargs)
        return val
    def IncRef(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellRenderer_IncRef,(self,) + _args, _kwargs)
        return val
    def DecRef(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellRenderer_DecRef,(self,) + _args, _kwargs)
        return val
    def Draw(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellRenderer_Draw,(self,) + _args, _kwargs)
        return val
    def GetBestSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellRenderer_GetBestSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def Clone(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellRenderer_Clone,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridCellRenderer instance at %s>" % (self.this,)
class wxGridCellRenderer(wxGridCellRendererPtr):
    def __init__(self,this):
        self.this = this




class wxPyGridCellRendererPtr(wxGridCellRendererPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellRenderer__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_SetParameters(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellRenderer_base_SetParameters,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyGridCellRenderer instance at %s>" % (self.this,)
class wxPyGridCellRenderer(wxPyGridCellRendererPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxPyGridCellRenderer,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyGridCellRenderer)
        self._setOORInfo(self)




class wxGridCellStringRendererPtr(wxGridCellRendererPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellStringRenderer instance at %s>" % (self.this,)
class wxGridCellStringRenderer(wxGridCellStringRendererPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellStringRenderer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellNumberRendererPtr(wxGridCellStringRendererPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellNumberRenderer instance at %s>" % (self.this,)
class wxGridCellNumberRenderer(wxGridCellNumberRendererPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellNumberRenderer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellFloatRendererPtr(wxGridCellStringRendererPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetWidth(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellFloatRenderer_GetWidth,(self,) + _args, _kwargs)
        return val
    def SetWidth(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellFloatRenderer_SetWidth,(self,) + _args, _kwargs)
        return val
    def GetPrecision(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellFloatRenderer_GetPrecision,(self,) + _args, _kwargs)
        return val
    def SetPrecision(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellFloatRenderer_SetPrecision,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridCellFloatRenderer instance at %s>" % (self.this,)
class wxGridCellFloatRenderer(wxGridCellFloatRendererPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellFloatRenderer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellBoolRendererPtr(wxGridCellRendererPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellBoolRenderer instance at %s>" % (self.this,)
class wxGridCellBoolRenderer(wxGridCellBoolRendererPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellBoolRenderer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellDateTimeRendererPtr(wxGridCellStringRendererPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellDateTimeRenderer instance at %s>" % (self.this,)
class wxGridCellDateTimeRenderer(wxGridCellDateTimeRendererPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellDateTimeRenderer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellEnumRendererPtr(wxGridCellStringRendererPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellEnumRenderer instance at %s>" % (self.this,)
class wxGridCellEnumRenderer(wxGridCellEnumRendererPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellEnumRenderer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellAutoWrapStringRendererPtr(wxGridCellStringRendererPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellAutoWrapStringRenderer instance at %s>" % (self.this,)
class wxGridCellAutoWrapStringRenderer(wxGridCellAutoWrapStringRendererPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellAutoWrapStringRenderer,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellEditorPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setOORInfo(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor__setOORInfo,(self,) + _args, _kwargs)
        return val
    def IsCreated(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_IsCreated,(self,) + _args, _kwargs)
        return val
    def GetControl(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_GetControl,(self,) + _args, _kwargs)
        return val
    def SetControl(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_SetControl,(self,) + _args, _kwargs)
        return val
    def GetCellAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_GetCellAttr,(self,) + _args, _kwargs)
        return val
    def SetCellAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_SetCellAttr,(self,) + _args, _kwargs)
        return val
    def SetParameters(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_SetParameters,(self,) + _args, _kwargs)
        return val
    def IncRef(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_IncRef,(self,) + _args, _kwargs)
        return val
    def DecRef(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_DecRef,(self,) + _args, _kwargs)
        return val
    def Create(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_Create,(self,) + _args, _kwargs)
        return val
    def BeginEdit(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_BeginEdit,(self,) + _args, _kwargs)
        return val
    def EndEdit(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_EndEdit,(self,) + _args, _kwargs)
        return val
    def Reset(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_Reset,(self,) + _args, _kwargs)
        return val
    def Clone(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_Clone,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_SetSize,(self,) + _args, _kwargs)
        return val
    def Show(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_Show,(self,) + _args, _kwargs)
        return val
    def PaintBackground(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_PaintBackground,(self,) + _args, _kwargs)
        return val
    def IsAcceptedKey(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_IsAcceptedKey,(self,) + _args, _kwargs)
        return val
    def StartingKey(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_StartingKey,(self,) + _args, _kwargs)
        return val
    def StartingClick(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_StartingClick,(self,) + _args, _kwargs)
        return val
    def HandleReturn(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_HandleReturn,(self,) + _args, _kwargs)
        return val
    def Destroy(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellEditor_Destroy,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridCellEditor instance at %s>" % (self.this,)
class wxGridCellEditor(wxGridCellEditorPtr):
    def __init__(self,this):
        self.this = this




class wxPyGridCellEditorPtr(wxGridCellEditorPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_SetSize(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor_base_SetSize,(self,) + _args, _kwargs)
        return val
    def base_Show(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor_base_Show,(self,) + _args, _kwargs)
        return val
    def base_PaintBackground(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor_base_PaintBackground,(self,) + _args, _kwargs)
        return val
    def base_IsAcceptedKey(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor_base_IsAcceptedKey,(self,) + _args, _kwargs)
        return val
    def base_StartingKey(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor_base_StartingKey,(self,) + _args, _kwargs)
        return val
    def base_StartingClick(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor_base_StartingClick,(self,) + _args, _kwargs)
        return val
    def base_HandleReturn(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor_base_HandleReturn,(self,) + _args, _kwargs)
        return val
    def base_Destroy(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor_base_Destroy,(self,) + _args, _kwargs)
        return val
    def base_SetParameters(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellEditor_base_SetParameters,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyGridCellEditor instance at %s>" % (self.this,)
class wxPyGridCellEditor(wxPyGridCellEditorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxPyGridCellEditor,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyGridCellEditor)
        self._setOORInfo(self)




class wxGridCellTextEditorPtr(wxGridCellEditorPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellTextEditor instance at %s>" % (self.this,)
class wxGridCellTextEditor(wxGridCellTextEditorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellTextEditor,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellNumberEditorPtr(wxGridCellTextEditorPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellNumberEditor instance at %s>" % (self.this,)
class wxGridCellNumberEditor(wxGridCellNumberEditorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellNumberEditor,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellFloatEditorPtr(wxGridCellTextEditorPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellFloatEditor instance at %s>" % (self.this,)
class wxGridCellFloatEditor(wxGridCellFloatEditorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellFloatEditor,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellBoolEditorPtr(wxGridCellEditorPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellBoolEditor instance at %s>" % (self.this,)
class wxGridCellBoolEditor(wxGridCellBoolEditorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellBoolEditor,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellChoiceEditorPtr(wxGridCellEditorPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellChoiceEditor instance at %s>" % (self.this,)
class wxGridCellChoiceEditor(wxGridCellChoiceEditorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellChoiceEditor,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellEnumEditorPtr(wxGridCellChoiceEditorPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellEnumEditor instance at %s>" % (self.this,)
class wxGridCellEnumEditor(wxGridCellEnumEditorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellEnumEditor,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellAutoWrapStringEditorPtr(wxGridCellTextEditorPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridCellAutoWrapStringEditor instance at %s>" % (self.this,)
class wxGridCellAutoWrapStringEditor(wxGridCellAutoWrapStringEditorPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellAutoWrapStringEditor,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellAttrPtr :
    Any = gridc.wxGridCellAttr_Any
    Default = gridc.wxGridCellAttr_Default
    Cell = gridc.wxGridCellAttr_Cell
    Row = gridc.wxGridCellAttr_Row
    Col = gridc.wxGridCellAttr_Col
    Merged = gridc.wxGridCellAttr_Merged
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setOORInfo(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr__setOORInfo,(self,) + _args, _kwargs)
        return val
    def Clone(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_Clone,(self,) + _args, _kwargs)
        return val
    def MergeWith(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_MergeWith,(self,) + _args, _kwargs)
        return val
    def IncRef(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_IncRef,(self,) + _args, _kwargs)
        return val
    def DecRef(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_DecRef,(self,) + _args, _kwargs)
        return val
    def SetTextColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetTextColour,(self,) + _args, _kwargs)
        return val
    def SetBackgroundColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetBackgroundColour,(self,) + _args, _kwargs)
        return val
    def SetFont(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetFont,(self,) + _args, _kwargs)
        return val
    def SetAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetAlignment,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetSize,(self,) + _args, _kwargs)
        return val
    def SetOverflow(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetOverflow,(self,) + _args, _kwargs)
        return val
    def SetReadOnly(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetReadOnly,(self,) + _args, _kwargs)
        return val
    def SetRenderer(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetRenderer,(self,) + _args, _kwargs)
        return val
    def SetEditor(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetEditor,(self,) + _args, _kwargs)
        return val
    def SetKind(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetKind,(self,) + _args, _kwargs)
        return val
    def HasTextColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_HasTextColour,(self,) + _args, _kwargs)
        return val
    def HasBackgroundColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_HasBackgroundColour,(self,) + _args, _kwargs)
        return val
    def HasFont(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_HasFont,(self,) + _args, _kwargs)
        return val
    def HasAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_HasAlignment,(self,) + _args, _kwargs)
        return val
    def HasRenderer(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_HasRenderer,(self,) + _args, _kwargs)
        return val
    def HasEditor(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_HasEditor,(self,) + _args, _kwargs)
        return val
    def HasReadWriteMode(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_HasReadWriteMode,(self,) + _args, _kwargs)
        return val
    def GetTextColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_GetTextColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetBackgroundColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_GetBackgroundColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetFont(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_GetFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def GetAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_GetAlignment,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_GetSize,(self,) + _args, _kwargs)
        return val
    def GetOverflow(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_GetOverflow,(self,) + _args, _kwargs)
        return val
    def GetRenderer(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_GetRenderer,(self,) + _args, _kwargs)
        return val
    def GetEditor(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_GetEditor,(self,) + _args, _kwargs)
        return val
    def IsReadOnly(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_IsReadOnly,(self,) + _args, _kwargs)
        return val
    def SetDefAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttr_SetDefAttr,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridCellAttr instance at %s>" % (self.this,)
class wxGridCellAttr(wxGridCellAttrPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellAttr,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridCellAttrProviderPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setOORInfo(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttrProvider__setOORInfo,(self,) + _args, _kwargs)
        return val
    def GetAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttrProvider_GetAttr,(self,) + _args, _kwargs)
        return val
    def SetAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttrProvider_SetAttr,(self,) + _args, _kwargs)
        return val
    def SetRowAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttrProvider_SetRowAttr,(self,) + _args, _kwargs)
        return val
    def SetColAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttrProvider_SetColAttr,(self,) + _args, _kwargs)
        return val
    def UpdateAttrRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttrProvider_UpdateAttrRows,(self,) + _args, _kwargs)
        return val
    def UpdateAttrCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellAttrProvider_UpdateAttrCols,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridCellAttrProvider instance at %s>" % (self.this,)
class wxGridCellAttrProvider(wxGridCellAttrProviderPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellAttrProvider,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxPyGridCellAttrProviderPtr(wxGridCellAttrProviderPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellAttrProvider__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_GetAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellAttrProvider_base_GetAttr,(self,) + _args, _kwargs)
        return val
    def base_SetAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellAttrProvider_base_SetAttr,(self,) + _args, _kwargs)
        return val
    def base_SetRowAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellAttrProvider_base_SetRowAttr,(self,) + _args, _kwargs)
        return val
    def base_SetColAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridCellAttrProvider_base_SetColAttr,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyGridCellAttrProvider instance at %s>" % (self.this,)
class wxPyGridCellAttrProvider(wxPyGridCellAttrProviderPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxPyGridCellAttrProvider,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyGridCellAttrProvider)




class wxGridTableBasePtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setOORInfo(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase__setOORInfo,(self,) + _args, _kwargs)
        return val
    def SetAttrProvider(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetAttrProvider,(self,) + _args, _kwargs)
        return val
    def GetAttrProvider(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetAttrProvider,(self,) + _args, _kwargs)
        return val
    def SetView(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetView,(self,) + _args, _kwargs)
        return val
    def GetView(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetView,(self,) + _args, _kwargs)
        return val
    def GetNumberRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetNumberRows,(self,) + _args, _kwargs)
        return val
    def GetNumberCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetNumberCols,(self,) + _args, _kwargs)
        return val
    def IsEmptyCell(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_IsEmptyCell,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetValue,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetValue,(self,) + _args, _kwargs)
        return val
    def GetTypeName(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetTypeName,(self,) + _args, _kwargs)
        return val
    def CanGetValueAs(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_CanGetValueAs,(self,) + _args, _kwargs)
        return val
    def CanSetValueAs(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_CanSetValueAs,(self,) + _args, _kwargs)
        return val
    def GetValueAsLong(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetValueAsLong,(self,) + _args, _kwargs)
        return val
    def GetValueAsDouble(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetValueAsDouble,(self,) + _args, _kwargs)
        return val
    def GetValueAsBool(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetValueAsBool,(self,) + _args, _kwargs)
        return val
    def SetValueAsLong(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetValueAsLong,(self,) + _args, _kwargs)
        return val
    def SetValueAsDouble(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetValueAsDouble,(self,) + _args, _kwargs)
        return val
    def SetValueAsBool(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetValueAsBool,(self,) + _args, _kwargs)
        return val
    def Clear(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_Clear,(self,) + _args, _kwargs)
        return val
    def InsertRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_InsertRows,(self,) + _args, _kwargs)
        return val
    def AppendRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_AppendRows,(self,) + _args, _kwargs)
        return val
    def DeleteRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_DeleteRows,(self,) + _args, _kwargs)
        return val
    def InsertCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_InsertCols,(self,) + _args, _kwargs)
        return val
    def AppendCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_AppendCols,(self,) + _args, _kwargs)
        return val
    def DeleteCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_DeleteCols,(self,) + _args, _kwargs)
        return val
    def GetRowLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetRowLabelValue,(self,) + _args, _kwargs)
        return val
    def GetColLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetColLabelValue,(self,) + _args, _kwargs)
        return val
    def SetRowLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetRowLabelValue,(self,) + _args, _kwargs)
        return val
    def SetColLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetColLabelValue,(self,) + _args, _kwargs)
        return val
    def CanHaveAttributes(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_CanHaveAttributes,(self,) + _args, _kwargs)
        return val
    def GetAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_GetAttr,(self,) + _args, _kwargs)
        return val
    def SetAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetAttr,(self,) + _args, _kwargs)
        return val
    def SetRowAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetRowAttr,(self,) + _args, _kwargs)
        return val
    def SetColAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableBase_SetColAttr,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridTableBase instance at %s>" % (self.this,)
class wxGridTableBase(wxGridTableBasePtr):
    def __init__(self,this):
        self.this = this




class wxPyGridTableBasePtr(wxGridTableBasePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def Destroy(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_Destroy,(self,) + _args, _kwargs)
        return val
    def base_GetTypeName(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_GetTypeName,(self,) + _args, _kwargs)
        return val
    def base_CanGetValueAs(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_CanGetValueAs,(self,) + _args, _kwargs)
        return val
    def base_CanSetValueAs(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_CanSetValueAs,(self,) + _args, _kwargs)
        return val
    def base_Clear(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_Clear,(self,) + _args, _kwargs)
        return val
    def base_InsertRows(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_InsertRows,(self,) + _args, _kwargs)
        return val
    def base_AppendRows(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_AppendRows,(self,) + _args, _kwargs)
        return val
    def base_DeleteRows(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_DeleteRows,(self,) + _args, _kwargs)
        return val
    def base_InsertCols(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_InsertCols,(self,) + _args, _kwargs)
        return val
    def base_AppendCols(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_AppendCols,(self,) + _args, _kwargs)
        return val
    def base_DeleteCols(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_DeleteCols,(self,) + _args, _kwargs)
        return val
    def base_GetRowLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_GetRowLabelValue,(self,) + _args, _kwargs)
        return val
    def base_GetColLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_GetColLabelValue,(self,) + _args, _kwargs)
        return val
    def base_SetRowLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_SetRowLabelValue,(self,) + _args, _kwargs)
        return val
    def base_SetColLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_SetColLabelValue,(self,) + _args, _kwargs)
        return val
    def base_CanHaveAttributes(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_CanHaveAttributes,(self,) + _args, _kwargs)
        return val
    def base_GetAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_GetAttr,(self,) + _args, _kwargs)
        return val
    def base_SetAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_SetAttr,(self,) + _args, _kwargs)
        return val
    def base_SetRowAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_SetRowAttr,(self,) + _args, _kwargs)
        return val
    def base_SetColAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxPyGridTableBase_base_SetColAttr,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyGridTableBase instance at %s>" % (self.this,)
class wxPyGridTableBase(wxPyGridTableBasePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxPyGridTableBase,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyGridTableBase)
        self._setOORInfo(self)




class wxGridStringTablePtr(wxGridTableBasePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxGridStringTable instance at %s>" % (self.this,)
class wxGridStringTable(wxGridStringTablePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridStringTable,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridTableMessagePtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gridc.delete_wxGridTableMessage):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def SetTableObject(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableMessage_SetTableObject,(self,) + _args, _kwargs)
        return val
    def GetTableObject(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableMessage_GetTableObject,(self,) + _args, _kwargs)
        return val
    def SetId(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableMessage_SetId,(self,) + _args, _kwargs)
        return val
    def GetId(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableMessage_GetId,(self,) + _args, _kwargs)
        return val
    def SetCommandInt(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableMessage_SetCommandInt,(self,) + _args, _kwargs)
        return val
    def GetCommandInt(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableMessage_GetCommandInt,(self,) + _args, _kwargs)
        return val
    def SetCommandInt2(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableMessage_SetCommandInt2,(self,) + _args, _kwargs)
        return val
    def GetCommandInt2(self, *_args, **_kwargs):
        val = apply(gridc.wxGridTableMessage_GetCommandInt2,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridTableMessage instance at %s>" % (self.this,)
class wxGridTableMessage(wxGridTableMessagePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridTableMessage,_args,_kwargs)
        self.thisown = 1




class wxGridCellCoordsPtr :
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=gridc.delete_wxGridCellCoords):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellCoords_GetRow,(self,) + _args, _kwargs)
        return val
    def SetRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellCoords_SetRow,(self,) + _args, _kwargs)
        return val
    def GetCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellCoords_GetCol,(self,) + _args, _kwargs)
        return val
    def SetCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellCoords_SetCol,(self,) + _args, _kwargs)
        return val
    def Set(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellCoords_Set,(self,) + _args, _kwargs)
        return val
    def asTuple(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellCoords_asTuple,(self,) + _args, _kwargs)
        return val
    def __cmp__(self, *_args, **_kwargs):
        val = apply(gridc.wxGridCellCoords___cmp__,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridCellCoords instance at %s>" % (self.this,)
    
    def __str__(self):                   return str(self.asTuple())
    def __repr__(self):                  return 'wxGridCellCoords'+str(self.asTuple())
    def __len__(self):                   return len(self.asTuple())
    def __getitem__(self, index):        return self.asTuple()[index]
    def __setitem__(self, index, val):
        if index == 0: self.SetRow(val)
        elif index == 1: self.SetCol(val)
        else: raise IndexError
    
class wxGridCellCoords(wxGridCellCoordsPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridCellCoords,_args,_kwargs)
        self.thisown = 1




class wxGridPtr(wxScrolledWindowPtr):
    wxGridSelectCells = gridc.wxGrid_wxGridSelectCells
    wxGridSelectRows = gridc.wxGrid_wxGridSelectRows
    wxGridSelectColumns = gridc.wxGrid_wxGridSelectColumns
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def CreateGrid(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_CreateGrid,(self,) + _args, _kwargs)
        return val
    def SetSelectionMode(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetSelectionMode,(self,) + _args, _kwargs)
        return val
    def GetSelectionMode(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetSelectionMode,(self,) + _args, _kwargs)
        return val
    def GetNumberRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetNumberRows,(self,) + _args, _kwargs)
        return val
    def GetNumberCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetNumberCols,(self,) + _args, _kwargs)
        return val
    def ProcessTableMessage(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_ProcessTableMessage,(self,) + _args, _kwargs)
        return val
    def GetTable(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetTable,(self,) + _args, _kwargs)
        return val
    def SetTable(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetTable,(self,) + _args, _kwargs)
        return val
    def ClearGrid(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_ClearGrid,(self,) + _args, _kwargs)
        return val
    def InsertRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_InsertRows,(self,) + _args, _kwargs)
        return val
    def AppendRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_AppendRows,(self,) + _args, _kwargs)
        return val
    def DeleteRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DeleteRows,(self,) + _args, _kwargs)
        return val
    def InsertCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_InsertCols,(self,) + _args, _kwargs)
        return val
    def AppendCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_AppendCols,(self,) + _args, _kwargs)
        return val
    def DeleteCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DeleteCols,(self,) + _args, _kwargs)
        return val
    def DrawCellHighlight(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DrawCellHighlight,(self,) + _args, _kwargs)
        return val
    def DrawTextRectangle(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DrawTextRectangle,(self,) + _args, _kwargs)
        return val
    def GetTextBoxSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetTextBoxSize,(self,) + _args, _kwargs)
        return val
    def BeginBatch(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_BeginBatch,(self,) + _args, _kwargs)
        return val
    def EndBatch(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_EndBatch,(self,) + _args, _kwargs)
        return val
    def GetBatchCount(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetBatchCount,(self,) + _args, _kwargs)
        return val
    def ForceRefresh(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_ForceRefresh,(self,) + _args, _kwargs)
        return val
    def Refresh(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_Refresh,(self,) + _args, _kwargs)
        return val
    def IsEditable(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_IsEditable,(self,) + _args, _kwargs)
        return val
    def EnableEditing(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_EnableEditing,(self,) + _args, _kwargs)
        return val
    def EnableCellEditControl(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_EnableCellEditControl,(self,) + _args, _kwargs)
        return val
    def DisableCellEditControl(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DisableCellEditControl,(self,) + _args, _kwargs)
        return val
    def CanEnableCellControl(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_CanEnableCellControl,(self,) + _args, _kwargs)
        return val
    def IsCellEditControlEnabled(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_IsCellEditControlEnabled,(self,) + _args, _kwargs)
        return val
    def IsCellEditControlShown(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_IsCellEditControlShown,(self,) + _args, _kwargs)
        return val
    def IsCurrentCellReadOnly(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_IsCurrentCellReadOnly,(self,) + _args, _kwargs)
        return val
    def ShowCellEditControl(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_ShowCellEditControl,(self,) + _args, _kwargs)
        return val
    def HideCellEditControl(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_HideCellEditControl,(self,) + _args, _kwargs)
        return val
    def SaveEditControlValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SaveEditControlValue,(self,) + _args, _kwargs)
        return val
    def XYToCell(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_XYToCell,(self,) + _args, _kwargs)
        if val: val = wxGridCellCoordsPtr(val) ; val.thisown = 1
        return val
    def YToRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_YToRow,(self,) + _args, _kwargs)
        return val
    def XToCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_XToCol,(self,) + _args, _kwargs)
        return val
    def YToEdgeOfRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_YToEdgeOfRow,(self,) + _args, _kwargs)
        return val
    def XToEdgeOfCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_XToEdgeOfCol,(self,) + _args, _kwargs)
        return val
    def CellToRect(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_CellToRect,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def GetGridCursorRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetGridCursorRow,(self,) + _args, _kwargs)
        return val
    def GetGridCursorCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetGridCursorCol,(self,) + _args, _kwargs)
        return val
    def IsVisible(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_IsVisible,(self,) + _args, _kwargs)
        return val
    def MakeCellVisible(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MakeCellVisible,(self,) + _args, _kwargs)
        return val
    def SetGridCursor(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetGridCursor,(self,) + _args, _kwargs)
        return val
    def MoveCursorUp(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MoveCursorUp,(self,) + _args, _kwargs)
        return val
    def MoveCursorDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MoveCursorDown,(self,) + _args, _kwargs)
        return val
    def MoveCursorLeft(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MoveCursorLeft,(self,) + _args, _kwargs)
        return val
    def MoveCursorRight(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MoveCursorRight,(self,) + _args, _kwargs)
        return val
    def MovePageDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MovePageDown,(self,) + _args, _kwargs)
        return val
    def MovePageUp(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MovePageUp,(self,) + _args, _kwargs)
        return val
    def MoveCursorUpBlock(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MoveCursorUpBlock,(self,) + _args, _kwargs)
        return val
    def MoveCursorDownBlock(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MoveCursorDownBlock,(self,) + _args, _kwargs)
        return val
    def MoveCursorLeftBlock(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MoveCursorLeftBlock,(self,) + _args, _kwargs)
        return val
    def MoveCursorRightBlock(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_MoveCursorRightBlock,(self,) + _args, _kwargs)
        return val
    def GetDefaultRowLabelSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultRowLabelSize,(self,) + _args, _kwargs)
        return val
    def GetRowLabelSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetRowLabelSize,(self,) + _args, _kwargs)
        return val
    def GetDefaultColLabelSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultColLabelSize,(self,) + _args, _kwargs)
        return val
    def GetColLabelSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetColLabelSize,(self,) + _args, _kwargs)
        return val
    def GetLabelBackgroundColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetLabelBackgroundColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetLabelTextColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetLabelTextColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetLabelFont(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetLabelFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def GetRowLabelAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetRowLabelAlignment,(self,) + _args, _kwargs)
        return val
    def GetColLabelAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetColLabelAlignment,(self,) + _args, _kwargs)
        return val
    def GetRowLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetRowLabelValue,(self,) + _args, _kwargs)
        return val
    def GetColLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetColLabelValue,(self,) + _args, _kwargs)
        return val
    def GetGridLineColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetGridLineColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetCellHighlightColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellHighlightColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetCellHighlightPenWidth(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellHighlightPenWidth,(self,) + _args, _kwargs)
        return val
    def GetCellHighlightROPenWidth(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellHighlightROPenWidth,(self,) + _args, _kwargs)
        return val
    def SetRowLabelSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetRowLabelSize,(self,) + _args, _kwargs)
        return val
    def SetColLabelSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColLabelSize,(self,) + _args, _kwargs)
        return val
    def SetLabelBackgroundColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetLabelBackgroundColour,(self,) + _args, _kwargs)
        return val
    def SetLabelTextColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetLabelTextColour,(self,) + _args, _kwargs)
        return val
    def SetLabelFont(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetLabelFont,(self,) + _args, _kwargs)
        return val
    def SetRowLabelAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetRowLabelAlignment,(self,) + _args, _kwargs)
        return val
    def SetColLabelAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColLabelAlignment,(self,) + _args, _kwargs)
        return val
    def SetRowLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetRowLabelValue,(self,) + _args, _kwargs)
        return val
    def SetColLabelValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColLabelValue,(self,) + _args, _kwargs)
        return val
    def SetGridLineColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetGridLineColour,(self,) + _args, _kwargs)
        return val
    def SetCellHighlightColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellHighlightColour,(self,) + _args, _kwargs)
        return val
    def SetCellHighlightPenWidth(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellHighlightPenWidth,(self,) + _args, _kwargs)
        return val
    def SetCellHighlightROPenWidth(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellHighlightROPenWidth,(self,) + _args, _kwargs)
        return val
    def EnableDragRowSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_EnableDragRowSize,(self,) + _args, _kwargs)
        return val
    def DisableDragRowSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DisableDragRowSize,(self,) + _args, _kwargs)
        return val
    def CanDragRowSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_CanDragRowSize,(self,) + _args, _kwargs)
        return val
    def EnableDragColSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_EnableDragColSize,(self,) + _args, _kwargs)
        return val
    def DisableDragColSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DisableDragColSize,(self,) + _args, _kwargs)
        return val
    def CanDragColSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_CanDragColSize,(self,) + _args, _kwargs)
        return val
    def EnableDragGridSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_EnableDragGridSize,(self,) + _args, _kwargs)
        return val
    def DisableDragGridSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DisableDragGridSize,(self,) + _args, _kwargs)
        return val
    def CanDragGridSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_CanDragGridSize,(self,) + _args, _kwargs)
        return val
    def SetAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetAttr,(self,) + _args, _kwargs)
        return val
    def SetRowAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetRowAttr,(self,) + _args, _kwargs)
        return val
    def SetColAttr(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColAttr,(self,) + _args, _kwargs)
        return val
    def SetColFormatBool(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColFormatBool,(self,) + _args, _kwargs)
        return val
    def SetColFormatNumber(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColFormatNumber,(self,) + _args, _kwargs)
        return val
    def SetColFormatFloat(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColFormatFloat,(self,) + _args, _kwargs)
        return val
    def SetColFormatCustom(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColFormatCustom,(self,) + _args, _kwargs)
        return val
    def EnableGridLines(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_EnableGridLines,(self,) + _args, _kwargs)
        return val
    def GridLinesEnabled(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GridLinesEnabled,(self,) + _args, _kwargs)
        return val
    def GetDefaultRowSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultRowSize,(self,) + _args, _kwargs)
        return val
    def GetRowSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetRowSize,(self,) + _args, _kwargs)
        return val
    def GetDefaultColSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultColSize,(self,) + _args, _kwargs)
        return val
    def GetColSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetColSize,(self,) + _args, _kwargs)
        return val
    def GetDefaultCellBackgroundColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultCellBackgroundColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetCellBackgroundColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellBackgroundColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetDefaultCellTextColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultCellTextColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetCellTextColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellTextColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetDefaultCellFont(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultCellFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def GetCellFont(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def GetDefaultCellAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultCellAlignment,(self,) + _args, _kwargs)
        return val
    def GetCellAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellAlignment,(self,) + _args, _kwargs)
        return val
    def GetDefaultCellOverflow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultCellOverflow,(self,) + _args, _kwargs)
        return val
    def GetCellOverflow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellOverflow,(self,) + _args, _kwargs)
        return val
    def GetCellSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellSize,(self,) + _args, _kwargs)
        return val
    def SetDefaultRowSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetDefaultRowSize,(self,) + _args, _kwargs)
        return val
    def SetRowSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetRowSize,(self,) + _args, _kwargs)
        return val
    def SetDefaultColSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetDefaultColSize,(self,) + _args, _kwargs)
        return val
    def SetColSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColSize,(self,) + _args, _kwargs)
        return val
    def AutoSizeColumn(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_AutoSizeColumn,(self,) + _args, _kwargs)
        return val
    def AutoSizeRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_AutoSizeRow,(self,) + _args, _kwargs)
        return val
    def AutoSizeColumns(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_AutoSizeColumns,(self,) + _args, _kwargs)
        return val
    def AutoSizeRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_AutoSizeRows,(self,) + _args, _kwargs)
        return val
    def AutoSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_AutoSize,(self,) + _args, _kwargs)
        return val
    def SetColMinimalWidth(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetColMinimalWidth,(self,) + _args, _kwargs)
        return val
    def SetRowMinimalHeight(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetRowMinimalHeight,(self,) + _args, _kwargs)
        return val
    def SetDefaultCellBackgroundColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetDefaultCellBackgroundColour,(self,) + _args, _kwargs)
        return val
    def SetCellBackgroundColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellBackgroundColour,(self,) + _args, _kwargs)
        return val
    def SetDefaultCellTextColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetDefaultCellTextColour,(self,) + _args, _kwargs)
        return val
    def SetCellTextColour(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellTextColour,(self,) + _args, _kwargs)
        return val
    def SetDefaultCellFont(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetDefaultCellFont,(self,) + _args, _kwargs)
        return val
    def SetCellFont(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellFont,(self,) + _args, _kwargs)
        return val
    def SetDefaultCellAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetDefaultCellAlignment,(self,) + _args, _kwargs)
        return val
    def SetCellAlignment(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellAlignment,(self,) + _args, _kwargs)
        return val
    def SetDefaultCellOverflow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetDefaultCellOverflow,(self,) + _args, _kwargs)
        return val
    def SetCellOverflow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellOverflow,(self,) + _args, _kwargs)
        return val
    def SetCellSize(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellSize,(self,) + _args, _kwargs)
        return val
    def SetDefaultRenderer(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetDefaultRenderer,(self,) + _args, _kwargs)
        return val
    def SetCellRenderer(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellRenderer,(self,) + _args, _kwargs)
        return val
    def GetDefaultRenderer(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultRenderer,(self,) + _args, _kwargs)
        return val
    def GetCellRenderer(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellRenderer,(self,) + _args, _kwargs)
        return val
    def SetDefaultEditor(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetDefaultEditor,(self,) + _args, _kwargs)
        return val
    def SetCellEditor(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellEditor,(self,) + _args, _kwargs)
        return val
    def GetDefaultEditor(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultEditor,(self,) + _args, _kwargs)
        return val
    def GetCellEditor(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellEditor,(self,) + _args, _kwargs)
        return val
    def GetCellValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetCellValue,(self,) + _args, _kwargs)
        return val
    def SetCellValue(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetCellValue,(self,) + _args, _kwargs)
        return val
    def IsReadOnly(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_IsReadOnly,(self,) + _args, _kwargs)
        return val
    def SetReadOnly(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetReadOnly,(self,) + _args, _kwargs)
        return val
    def SelectRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SelectRow,(self,) + _args, _kwargs)
        return val
    def SelectCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SelectCol,(self,) + _args, _kwargs)
        return val
    def SelectBlock(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SelectBlock,(self,) + _args, _kwargs)
        return val
    def SelectAll(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SelectAll,(self,) + _args, _kwargs)
        return val
    def IsSelection(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_IsSelection,(self,) + _args, _kwargs)
        return val
    def ClearSelection(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_ClearSelection,(self,) + _args, _kwargs)
        return val
    def IsInSelection(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_IsInSelection,(self,) + _args, _kwargs)
        return val
    def GetSelectedCells(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetSelectedCells,(self,) + _args, _kwargs)
        return val
    def GetSelectionBlockTopLeft(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetSelectionBlockTopLeft,(self,) + _args, _kwargs)
        return val
    def GetSelectionBlockBottomRight(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetSelectionBlockBottomRight,(self,) + _args, _kwargs)
        return val
    def GetSelectedRows(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetSelectedRows,(self,) + _args, _kwargs)
        return val
    def GetSelectedCols(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetSelectedCols,(self,) + _args, _kwargs)
        return val
    def DeselectRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DeselectRow,(self,) + _args, _kwargs)
        return val
    def DeselectCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DeselectCol,(self,) + _args, _kwargs)
        return val
    def DeselectCell(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_DeselectCell,(self,) + _args, _kwargs)
        return val
    def BlockToDeviceRect(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_BlockToDeviceRect,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def GetSelectionBackground(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetSelectionBackground,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetSelectionForeground(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetSelectionForeground,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def SetSelectionBackground(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetSelectionBackground,(self,) + _args, _kwargs)
        return val
    def SetSelectionForeground(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetSelectionForeground,(self,) + _args, _kwargs)
        return val
    def RegisterDataType(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_RegisterDataType,(self,) + _args, _kwargs)
        return val
    def GetDefaultEditorForCell(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultEditorForCell,(self,) + _args, _kwargs)
        return val
    def GetDefaultRendererForCell(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultRendererForCell,(self,) + _args, _kwargs)
        return val
    def GetDefaultEditorForType(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultEditorForType,(self,) + _args, _kwargs)
        return val
    def GetDefaultRendererForType(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetDefaultRendererForType,(self,) + _args, _kwargs)
        return val
    def SetMargins(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_SetMargins,(self,) + _args, _kwargs)
        return val
    def GetGridWindow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetGridWindow,(self,) + _args, _kwargs)
        return val
    def GetGridRowLabelWindow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetGridRowLabelWindow,(self,) + _args, _kwargs)
        return val
    def GetGridColLabelWindow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetGridColLabelWindow,(self,) + _args, _kwargs)
        return val
    def GetGridCornerLabelWindow(self, *_args, **_kwargs):
        val = apply(gridc.wxGrid_GetGridCornerLabelWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGrid instance at %s>" % (self.this,)
class wxGrid(wxGridPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGrid,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxGridEventPtr(wxNotifyEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEvent_GetRow,(self,) + _args, _kwargs)
        return val
    def GetCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEvent_GetCol,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEvent_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def Selecting(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEvent_Selecting,(self,) + _args, _kwargs)
        return val
    def ControlDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEvent_ControlDown,(self,) + _args, _kwargs)
        return val
    def MetaDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEvent_MetaDown,(self,) + _args, _kwargs)
        return val
    def ShiftDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEvent_ShiftDown,(self,) + _args, _kwargs)
        return val
    def AltDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEvent_AltDown,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridEvent instance at %s>" % (self.this,)
class wxGridEvent(wxGridEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridEvent,_args,_kwargs)
        self.thisown = 1




class wxGridSizeEventPtr(wxNotifyEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetRowOrCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGridSizeEvent_GetRowOrCol,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(gridc.wxGridSizeEvent_GetPosition,(self,) + _args, _kwargs)
        if val: val = wxPointPtr(val) ; val.thisown = 1
        return val
    def ControlDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridSizeEvent_ControlDown,(self,) + _args, _kwargs)
        return val
    def MetaDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridSizeEvent_MetaDown,(self,) + _args, _kwargs)
        return val
    def ShiftDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridSizeEvent_ShiftDown,(self,) + _args, _kwargs)
        return val
    def AltDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridSizeEvent_AltDown,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridSizeEvent instance at %s>" % (self.this,)
class wxGridSizeEvent(wxGridSizeEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridSizeEvent,_args,_kwargs)
        self.thisown = 1




class wxGridRangeSelectEventPtr(wxNotifyEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetTopLeftCoords(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_GetTopLeftCoords,(self,) + _args, _kwargs)
        if val: val = wxGridCellCoordsPtr(val) ; val.thisown = 1
        return val
    def GetBottomRightCoords(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_GetBottomRightCoords,(self,) + _args, _kwargs)
        if val: val = wxGridCellCoordsPtr(val) ; val.thisown = 1
        return val
    def GetTopRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_GetTopRow,(self,) + _args, _kwargs)
        return val
    def GetBottomRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_GetBottomRow,(self,) + _args, _kwargs)
        return val
    def GetLeftCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_GetLeftCol,(self,) + _args, _kwargs)
        return val
    def GetRightCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_GetRightCol,(self,) + _args, _kwargs)
        return val
    def Selecting(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_Selecting,(self,) + _args, _kwargs)
        return val
    def ControlDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_ControlDown,(self,) + _args, _kwargs)
        return val
    def MetaDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_MetaDown,(self,) + _args, _kwargs)
        return val
    def ShiftDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_ShiftDown,(self,) + _args, _kwargs)
        return val
    def AltDown(self, *_args, **_kwargs):
        val = apply(gridc.wxGridRangeSelectEvent_AltDown,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridRangeSelectEvent instance at %s>" % (self.this,)
class wxGridRangeSelectEvent(wxGridRangeSelectEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridRangeSelectEvent,_args,_kwargs)
        self.thisown = 1




class wxGridEditorCreatedEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEditorCreatedEvent_GetRow,(self,) + _args, _kwargs)
        return val
    def GetCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEditorCreatedEvent_GetCol,(self,) + _args, _kwargs)
        return val
    def GetControl(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEditorCreatedEvent_GetControl,(self,) + _args, _kwargs)
        return val
    def SetRow(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEditorCreatedEvent_SetRow,(self,) + _args, _kwargs)
        return val
    def SetCol(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEditorCreatedEvent_SetCol,(self,) + _args, _kwargs)
        return val
    def SetControl(self, *_args, **_kwargs):
        val = apply(gridc.wxGridEditorCreatedEvent_SetControl,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxGridEditorCreatedEvent instance at %s>" % (self.this,)
class wxGridEditorCreatedEvent(wxGridEditorCreatedEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gridc.new_wxGridEditorCreatedEvent,_args,_kwargs)
        self.thisown = 1






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------

wxGRID_VALUE_STRING = gridc.wxGRID_VALUE_STRING
wxGRID_VALUE_BOOL = gridc.wxGRID_VALUE_BOOL
wxGRID_VALUE_NUMBER = gridc.wxGRID_VALUE_NUMBER
wxGRID_VALUE_FLOAT = gridc.wxGRID_VALUE_FLOAT
wxGRID_VALUE_CHOICE = gridc.wxGRID_VALUE_CHOICE
wxGRID_VALUE_TEXT = gridc.wxGRID_VALUE_TEXT
wxGRID_VALUE_LONG = gridc.wxGRID_VALUE_LONG
wxGRID_VALUE_CHOICEINT = gridc.wxGRID_VALUE_CHOICEINT
wxGRID_VALUE_DATETIME = gridc.wxGRID_VALUE_DATETIME
cvar = gridc.cvar
wxGridNoCellCoords = wxGridCellCoordsPtr(gridc.cvar.wxGridNoCellCoords)
wxGridNoCellRect = wxRectPtr(gridc.cvar.wxGridNoCellRect)
wxGRIDTABLE_REQUEST_VIEW_GET_VALUES = gridc.wxGRIDTABLE_REQUEST_VIEW_GET_VALUES
wxGRIDTABLE_REQUEST_VIEW_SEND_VALUES = gridc.wxGRIDTABLE_REQUEST_VIEW_SEND_VALUES
wxGRIDTABLE_NOTIFY_ROWS_INSERTED = gridc.wxGRIDTABLE_NOTIFY_ROWS_INSERTED
wxGRIDTABLE_NOTIFY_ROWS_APPENDED = gridc.wxGRIDTABLE_NOTIFY_ROWS_APPENDED
wxGRIDTABLE_NOTIFY_ROWS_DELETED = gridc.wxGRIDTABLE_NOTIFY_ROWS_DELETED
wxGRIDTABLE_NOTIFY_COLS_INSERTED = gridc.wxGRIDTABLE_NOTIFY_COLS_INSERTED
wxGRIDTABLE_NOTIFY_COLS_APPENDED = gridc.wxGRIDTABLE_NOTIFY_COLS_APPENDED
wxGRIDTABLE_NOTIFY_COLS_DELETED = gridc.wxGRIDTABLE_NOTIFY_COLS_DELETED
wxEVT_GRID_CELL_LEFT_CLICK = gridc.wxEVT_GRID_CELL_LEFT_CLICK
wxEVT_GRID_CELL_RIGHT_CLICK = gridc.wxEVT_GRID_CELL_RIGHT_CLICK
wxEVT_GRID_CELL_LEFT_DCLICK = gridc.wxEVT_GRID_CELL_LEFT_DCLICK
wxEVT_GRID_CELL_RIGHT_DCLICK = gridc.wxEVT_GRID_CELL_RIGHT_DCLICK
wxEVT_GRID_LABEL_LEFT_CLICK = gridc.wxEVT_GRID_LABEL_LEFT_CLICK
wxEVT_GRID_LABEL_RIGHT_CLICK = gridc.wxEVT_GRID_LABEL_RIGHT_CLICK
wxEVT_GRID_LABEL_LEFT_DCLICK = gridc.wxEVT_GRID_LABEL_LEFT_DCLICK
wxEVT_GRID_LABEL_RIGHT_DCLICK = gridc.wxEVT_GRID_LABEL_RIGHT_DCLICK
wxEVT_GRID_ROW_SIZE = gridc.wxEVT_GRID_ROW_SIZE
wxEVT_GRID_COL_SIZE = gridc.wxEVT_GRID_COL_SIZE
wxEVT_GRID_RANGE_SELECT = gridc.wxEVT_GRID_RANGE_SELECT
wxEVT_GRID_CELL_CHANGE = gridc.wxEVT_GRID_CELL_CHANGE
wxEVT_GRID_SELECT_CELL = gridc.wxEVT_GRID_SELECT_CELL
wxEVT_GRID_EDITOR_SHOWN = gridc.wxEVT_GRID_EDITOR_SHOWN
wxEVT_GRID_EDITOR_HIDDEN = gridc.wxEVT_GRID_EDITOR_HIDDEN
wxEVT_GRID_EDITOR_CREATED = gridc.wxEVT_GRID_EDITOR_CREATED


#-------------- USER INCLUDE -----------------------



# Stuff these names into the wx namespace so wxPyConstructObject can find them

wx.wxGridEventPtr                  = wxGridEventPtr
wx.wxGridSizeEventPtr              = wxGridSizeEventPtr
wx.wxGridRangeSelectEventPtr       = wxGridRangeSelectEventPtr
wx.wxGridEditorCreatedEventPtr     = wxGridEditorCreatedEventPtr
wx.wxGridCellRendererPtr           = wxGridCellRendererPtr
wx.wxPyGridCellRendererPtr         = wxPyGridCellRendererPtr
wx.wxGridCellEditorPtr             = wxGridCellEditorPtr
wx.wxPyGridCellEditorPtr           = wxPyGridCellEditorPtr
wx.wxGridCellAttrPtr               = wxGridCellAttrPtr
wx.wxGridCellAttrProviderPtr       = wxGridCellAttrProviderPtr
wx.wxPyGridCellAttrProviderPtr     = wxPyGridCellAttrProviderPtr
wx.wxGridTableBasePtr              = wxGridTableBasePtr
wx.wxPyGridTableBasePtr            = wxPyGridTableBasePtr
wx.wxGridTableMessagePtr           = wxGridTableMessagePtr
wx.wxGridCellCoordsPtr             = wxGridCellCoordsPtr
wx.wxGridPtr                       = wxGridPtr



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Menus.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object, EvtHandler
import Parameters as wx
from Window import Window


class FileHistory(Object):
    """"""

    def AddFileToHistory(self):
        """"""
        pass

    def AddFilesToMenu(self):
        """"""
        pass

    def AddFilesToThisMenu(self):
        """"""
        pass

    def GetCount(self):
        """"""
        pass

    def GetHistoryFile(self):
        """"""
        pass

    def GetMaxFiles(self):
        """"""
        pass

    def GetNoHistoryFiles(self):
        """"""
        pass

    def Load(self):
        """"""
        pass

    def RemoveFileFromHistory(self):
        """"""
        pass

    def RemoveMenu(self):
        """"""
        pass

    def Save(self):
        """"""
        pass

    def UseMenu(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class Menu(EvtHandler):
    """"""

    def Append(self):
        """"""
        pass

    def AppendCheckItem(self):
        """"""
        pass

    def AppendItem(self):
        """"""
        pass

    def AppendMenu(self):
        """"""
        pass

    def AppendRadioItem(self):
        """"""
        pass

    def AppendSeparator(self):
        """"""
        pass

    def Break(self):
        """"""
        pass

    def Check(self):
        """"""
        pass

    def Delete(self):
        """"""
        pass

    def DeleteItem(self):
        """"""
        pass

    def Destroy(self):
        """"""
        pass

    def DestroyId(self):
        """"""
        pass

    def DestroyItem(self):
        """"""
        pass

    def Enable(self):
        """"""
        pass

    def FindItem(self):
        """"""
        pass

    def FindItemById(self):
        """"""
        pass

    def GetEventHandler(self):
        """"""
        pass

    def GetHelpString(self):
        """"""
        pass

    def GetInvokingWindow(self):
        """"""
        pass

    def GetLabel(self):
        """"""
        pass

    def GetMenuItemCount(self):
        """"""
        pass

    def GetMenuItems(self):
        """"""
        pass

    def GetParent(self):
        """"""
        pass

    def GetStyle(self):
        """"""
        pass

    def GetTitle(self):
        """"""
        pass

    def Insert(self):
        """"""
        pass

    def InsertCheckItem(self):
        """"""
        pass

    def InsertItem(self):
        """"""
        pass

    def InsertMenu(self):
        """"""
        pass

    def InsertRadioItem(self):
        """"""
        pass

    def InsertSeparator(self):
        """"""
        pass

    def IsAttached(self):
        """"""
        pass

    def IsChecked(self):
        """"""
        pass

    def IsEnabled(self):
        """"""
        pass

    def Prepend(self):
        """"""
        pass

    def PrependCheckItem(self):
        """"""
        pass

    def PrependItem(self):
        """"""
        pass

    def PrependMenu(self):
        """"""
        pass

    def PrependRadioItem(self):
        """"""
        pass

    def PrependSeparator(self):
        """"""
        pass

    def Remove(self):
        """"""
        pass

    def RemoveItem(self):
        """"""
        pass

    def SetEventHandler(self):
        """"""
        pass

    def SetHelpString(self):
        """"""
        pass

    def SetInvokingWindow(self):
        """"""
        pass

    def SetLabel(self):
        """"""
        pass

    def SetParent(self):
        """"""
        pass

    def SetTitle(self):
        """"""
        pass

    def UpdateUI(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class MenuBar(Window):
    """"""

    def Append(self):
        """"""
        pass

    def Check(self):
        """"""
        pass

    def Enable(self):
        """"""
        pass

    def EnableTop(self):
        """"""
        pass

    def FindItemById(self):
        """"""
        pass

    def FindMenu(self):
        """"""
        pass

    def FindMenuItem(self):
        """"""
        pass

    def GetHelpString(self):
        """"""
        pass

    def GetLabel(self):
        """"""
        pass

    def GetLabelTop(self):
        """"""
        pass

    def GetMenu(self):
        """"""
        pass

    def GetMenuCount(self):
        """"""
        pass

    def Insert(self):
        """"""
        pass

    def IsChecked(self):
        """"""
        pass

    def IsEnabled(self):
        """"""
        pass

    def IsEnabledTop(self):
        """"""
        pass

    def Remove(self):
        """"""
        pass

    def Replace(self):
        """"""
        pass

    def SetHelpString(self):
        """"""
        pass

    def SetLabel(self):
        """"""
        pass

    def SetLabelTop(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

class MenuItem(Object):
    """"""

    def Check(self):
        """"""
        pass

    def Enable(self):
        """"""
        pass

    def GetAccel(self):
        """"""
        pass

    def GetBitmap(self):
        """"""
        pass

    def GetHelp(self):
        """"""
        pass

    def GetId(self):
        """"""
        pass

    def GetKind(self):
        """"""
        pass

    def GetLabel(self):
        """"""
        pass

    def GetMenu(self):
        """"""
        pass

    def GetSubMenu(self):
        """"""
        pass

    def GetText(self):
        """"""
        pass

    def IsCheckable(self):
        """"""
        pass

    def IsChecked(self):
        """"""
        pass

    def IsEnabled(self):
        """"""
        pass

    def IsSeparator(self):
        """"""
        pass

    def IsSubMenu(self):
        """"""
        pass

    def SetAccel(self):
        """"""
        pass

    def SetBitmap(self):
        """"""
        pass

    def SetCheckable(self):
        """"""
        pass

    def SetHelp(self):
        """"""
        pass

    def SetId(self):
        """"""
        pass

    def SetSubMenu(self):
        """"""
        pass

    def SetText(self):
        """"""
        pass

    def Toggle(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass





"""PyFillingApp is a python namespace inspection application."""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: PyFillingApp.py,v 1.5.2.3 2003/03/11 19:37:33 RD Exp $"
__revision__ = "$Revision: 1.5.2.3 $"[11:-2]

# We use this object to get more introspection when run standalone.
app = None

import filling

# These are imported just to have something interesting to inspect.
import crust
import interpreter
import introspect
import pseudo
import shell

import sys
from wxPython import wx

try:
    True
except NameError:
    True = 1==1
    False = 1==0


class App(filling.App):
    def OnInit(self):
        filling.App.OnInit(self)
        self.root = self.fillingFrame.filling.tree.root
        return True

def main():
    """Create and run the application."""
    global app
    app = App(0)
    app.fillingFrame.filling.tree.Expand(app.root)
    app.MainLoop()


if __name__ == '__main__':
    main()



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Config.py,v 1.1.2.1 2003/03/11 19:37:13 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


import Parameters as wx


class ConfigBase:
    """"""

    def DeleteAll(self):
        """"""
        pass

    def DeleteEntry(self):
        """"""
        pass

    def DeleteGroup(self):
        """"""
        pass

    def Exists(self):
        """"""
        pass

    def ExpandEnvVars(self):
        """"""
        pass

    def Flush(self):
        """"""
        pass

    def GetAppName(self):
        """"""
        pass

    def GetEntryType(self):
        """"""
        pass

    def GetFirstEntry(self):
        """"""
        pass

    def GetFirstGroup(self):
        """"""
        pass

    def GetNextEntry(self):
        """"""
        pass

    def GetNextGroup(self):
        """"""
        pass

    def GetNumberOfEntries(self):
        """"""
        pass

    def GetNumberOfGroups(self):
        """"""
        pass

    def GetPath(self):
        """"""
        pass

    def GetStyle(self):
        """"""
        pass

    def GetVendorName(self):
        """"""
        pass

    def HasEntry(self):
        """"""
        pass

    def HasGroup(self):
        """"""
        pass

    def IsExpandingEnvVars(self):
        """"""
        pass

    def IsRecordingDefaults(self):
        """"""
        pass

    def Read(self):
        """"""
        pass

    def ReadBool(self):
        """"""
        pass

    def ReadFloat(self):
        """"""
        pass

    def ReadInt(self):
        """"""
        pass

    def RenameEntry(self):
        """"""
        pass

    def RenameGroup(self):
        """"""
        pass

    def SetAppName(self):
        """"""
        pass

    def SetExpandEnvVars(self):
        """"""
        pass

    def SetPath(self):
        """"""
        pass

    def SetRecordDefaults(self):
        """"""
        pass

    def SetStyle(self):
        """"""
        pass

    def SetVendorName(self):
        """"""
        pass

    def Write(self):
        """"""
        pass

    def WriteBool(self):
        """"""
        pass

    def WriteFloat(self):
        """"""
        pass

    def WriteInt(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class Config(ConfigBase):
    """"""

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FileConfig(ConfigBase):
    """"""

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Events.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object
import Parameters as wx


class Event(Object):
    """"""

    def __init__(self):
        """"""
        pass

    def Clone(self):
        """"""
        pass

    def GetEventObject(self):
        """"""
        pass

    def GetEventType(self):
        """"""
        pass

    def GetId(self):
        """"""
        pass

    def GetSkipped(self):
        """"""
        pass

    def GetTimestamp(self):
        """"""
        pass

    def SetEventObject(self):
        """"""
        pass

    def SetEventType(self):
        """"""
        pass

    def SetId(self):
        """"""
        pass

    def SetTimestamp(self):
        """"""
        pass

    def Skip(self):
        """"""
        pass


class PyEvent(Event):
    """"""

    def GetSelf(self):
        """"""
        pass

    def SetSelf(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ActivateEvent(Event):
    """"""

    def GetActive(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class CalculateLayoutEvent(Event):
    """"""

    def GetFlags(self):
        """"""
        pass

    def GetRect(self):
        """"""
        pass

    def SetFlags(self):
        """"""
        pass

    def SetRect(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class CloseEvent(Event):
    """"""

    def CanVeto(self):
        """"""
        pass

    def GetLoggingOff(self):
        """"""
        pass

    def GetVeto(self):
        """"""
        pass

    def SetCanVeto(self):
        """"""
        pass

    def SetLoggingOff(self):
        """"""
        pass

    def Veto(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class CommandEvent(Event):
    """"""

    def __init__(self):
        """"""
        pass

    def Checked(self):
        """"""
        pass

    def GetClientData(self):
        """"""
        pass

    def GetExtraLong(self):
        """"""
        pass

    def GetInt(self):
        """"""
        pass

    def GetSelection(self):
        """"""
        pass

    def GetString(self):
        """"""
        pass

    def IsChecked(self):
        """"""
        pass

    def IsSelection(self):
        """"""
        pass

    def SetExtraLong(self):
        """"""
        pass

    def SetInt(self):
        """"""
        pass

    def SetString(self):
        """"""
        pass


class ChildFocusEvent(CommandEvent):
    """"""

    def GetWindow(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ContextMenuEvent(CommandEvent):
    """"""

    def GetPosition(self):
        """"""
        pass

    def SetPosition(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class DisplayChangedEvent(Event):
    """"""

    def __init__(self):
        """"""
        pass


class DropFilesEvent(Event):
    """"""

    def GetFiles(self):
        """"""
        pass

    def GetNumberOfFiles(self):
        """"""
        pass

    def GetPosition(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class EraseEvent(Event):
    """"""

    def GetDC(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FindDialogEvent(CommandEvent):
    """"""

    def GetDialog(self):
        """"""
        pass

    def GetFindString(self):
        """"""
        pass

    def GetFlags(self):
        """"""
        pass

    def GetReplaceString(self):
        """"""
        pass

    def SetFindString(self):
        """"""
        pass

    def SetFlags(self):
        """"""
        pass

    def SetReplaceString(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class FocusEvent(Event):
    """"""

    def __init__(self):
        """"""
        pass


class IconizeEvent(Event):
    """"""

    def Iconized(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class IdleEvent(Event):
    """"""

    def MoreRequested(self):
        """"""
        pass

    def RequestMore(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class InitDialogEvent(Event):
    """"""

    def __init__(self):
        """"""
        pass


class JoystickEvent(Event):
    """"""

    def ButtonDown(self):
        """"""
        pass

    def ButtonIsDown(self):
        """"""
        pass

    def ButtonUp(self):
        """"""
        pass

    def GetButtonChange(self):
        """"""
        pass

    def GetButtonState(self):
        """"""
        pass

    def GetJoystick(self):
        """"""
        pass

    def GetPosition(self):
        """"""
        pass

    def GetZPosition(self):
        """"""
        pass

    def IsButton(self):
        """"""
        pass

    def IsMove(self):
        """"""
        pass

    def IsZMove(self):
        """"""
        pass

    def SetButtonChange(self):
        """"""
        pass

    def SetButtonState(self):
        """"""
        pass

    def SetJoystick(self):
        """"""
        pass

    def SetPosition(self):
        """"""
        pass

    def SetZPosition(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class KeyEvent(Event):
    """"""

    def AltDown(self):
        """"""
        pass

    def ControlDown(self):
        """"""
        pass

    def GetKeyCode(self):
        """"""
        pass

    def GetPosition(self):
        """"""
        pass

    def GetPositionTuple(self):
        """"""
        pass

    def GetRawKeyCode(self):
        """"""
        pass

    def GetRawKeyFlags(self):
        """"""
        pass

    def GetX(self):
        """"""
        pass

    def GetY(self):
        """"""
        pass

    def HasModifiers(self):
        """"""
        pass

    def KeyCode(self):
        """"""
        pass

    def MetaDown(self):
        """"""
        pass

    def ShiftDown(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass


class MaximizeEvent(Event):
    """"""

    def __init__(self):
        """"""
        pass


class MenuEvent(Event):
    """"""

    def GetMenuId(self):
        """"""
        pass

    def IsPopup(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class MouseCaptureChangedEvent(Event):
    """"""

    def GetCapturedWindow(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class MouseEvent(Event):
    """"""

    def AltDown(self):
        """"""
        pass

    def Button(self):
        """"""
        pass

    def ButtonDClick(self):
        """"""
        pass

    def ButtonDown(self):
        """"""
        pass

    def ButtonIsDown(self):
        """"""
        pass

    def ButtonUp(self):
        """"""
        pass

    def ControlDown(self):
        """"""
        pass

    def Dragging(self):
        """"""
        pass

    def Entering(self):
        """"""
        pass

    def GetLinesPerAction(self):
        """"""
        pass

    def GetLogicalPosition(self):
        """"""
        pass

    def GetPosition(self):
        """"""
        pass

    def GetPositionTuple(self):
        """"""
        pass

    def GetWheelDelta(self):
        """"""
        pass

    def GetWheelRotation(self):
        """"""
        pass

    def GetX(self):
        """"""
        pass

    def GetY(self):
        """"""
        pass

    def IsButton(self):
        """"""
        pass

    def Leaving(self):
        """"""
        pass

    def LeftDClick(self):
        """"""
        pass

    def LeftDown(self):
        """"""
        pass

    def LeftIsDown(self):
        """"""
        pass

    def LeftUp(self):
        """"""
        pass

    def MetaDown(self):
        """"""
        pass

    def MiddleDClick(self):
        """"""
        pass

    def MiddleDown(self):
        """"""
        pass

    def MiddleIsDown(self):
        """"""
        pass

    def MiddleUp(self):
        """"""
        pass

    def Moving(self):
        """"""
        pass

    def RightDClick(self):
        """"""
        pass

    def RightDown(self):
        """"""
        pass

    def RightIsDown(self):
        """"""
        pass

    def RightUp(self):
        """"""
        pass

    def ShiftDown(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass


class MoveEvent(Event):
    """"""

    def GetPosition(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class NavigationKeyEvent(Event):
    """"""

    def GetCurrentFocus(self):
        """"""
        pass

    def GetDirection(self):
        """"""
        pass

    def IsWindowChange(self):
        """"""
        pass

    def SetCurrentFocus(self):
        """"""
        pass

    def SetDirection(self):
        """"""
        pass

    def SetWindowChange(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class NotifyEvent(CommandEvent):
    """"""

    def __init__(self):
        """"""
        pass

    def Allow(self):
        """"""
        pass

    def IsAllowed(self):
        """"""
        pass

    def Veto(self):
        """"""
        pass


class ListEvent(NotifyEvent):
    """"""

    def GetCacheFrom(self):
        """"""
        pass

    def GetCacheTo(self):
        """"""
        pass

    def GetCode(self):
        """"""
        pass

    def GetColumn(self):
        """"""
        pass

    def GetData(self):
        """"""
        pass

    def GetImage(self):
        """"""
        pass

    def GetIndex(self):
        """"""
        pass

    def GetItem(self):
        """"""
        pass

    def GetKeyCode(self):
        """"""
        pass

    def GetLabel(self):
        """"""
        pass

    def GetMask(self):
        """"""
        pass

    def GetPoint(self):
        """"""
        pass

    def GetText(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass


class NotebookEvent(NotifyEvent):

    def __init__(self, commandType=wx.EVT_NULL, id=0, nSel=-1, nOldSel=-1):
        """"""
        pass

    def GetSelection(self):
        """"""
        pass
    
    def GetOldSelection(self):
        """"""
        pass
    
    def SetOldSelection(self, page):
        """"""
        pass

    def SetSelection(self, page):
        """"""
        pass


class PaintEvent(Event):
    """"""

    def __init__(self):
        """"""
        pass


class PaletteChangedEvent(Event):
    """"""

    def GetChangedWindow(self):
        """"""
        pass

    def SetChangedWindow(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ProcessEvent(Event):
    """"""

    def GetExitCode(self):
        """"""
        pass

    def GetPid(self):
        """"""
        pass

    def __getattr__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def __setattr__(self):
        """"""
        pass


class PyCommandEvent(CommandEvent):
    """"""

    def GetSelf(self):
        """"""
        pass

    def SetSelf(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class QueryLayoutInfoEvent(Event):
    """"""

    def GetAlignment(self):
        """"""
        pass

    def GetFlags(self):
        """"""
        pass

    def GetOrientation(self):
        """"""
        pass

    def GetRequestedLength(self):
        """"""
        pass

    def GetSize(self):
        """"""
        pass

    def SetAlignment(self):
        """"""
        pass

    def SetFlags(self):
        """"""
        pass

    def SetOrientation(self):
        """"""
        pass

    def SetRequestedLength(self):
        """"""
        pass

    def SetSize(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class QueryNewPaletteEvent(Event):
    """"""

    def GetPaletteRealized(self):
        """"""
        pass

    def SetPaletteRealized(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SashEvent(CommandEvent):
    """"""

    def GetDragRect(self):
        """"""
        pass

    def GetDragStatus(self):
        """"""
        pass

    def GetEdge(self):
        """"""
        pass

    def SetDragRect(self):
        """"""
        pass

    def SetDragStatus(self):
        """"""
        pass

    def SetEdge(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ScrollEvent(CommandEvent):
    """"""

    def GetOrientation(self):
        """"""
        pass

    def GetPosition(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ScrollWinEvent(Event):
    """"""

    def GetOrientation(self):
        """"""
        pass

    def GetPosition(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SetCursorEvent(Event):
    """"""

    def GetCursor(self):
        """"""
        pass

    def GetX(self):
        """"""
        pass

    def GetY(self):
        """"""
        pass

    def HasCursor(self):
        """"""
        pass

    def SetCursor(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class ShowEvent(Event):
    """"""

    def GetShow(self):
        """"""
        pass

    def SetShow(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SizeEvent(Event):
    """"""

    def GetSize(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SpinEvent(ScrollEvent):
    """"""

    def __init__(self):
        """"""
        pass


class SplitterEvent(NotifyEvent):
    """"""

    def GetSashPosition(self):
        """"""
        pass

    def GetWindowBeingRemoved(self):
        """"""
        pass

    def GetX(self):
        """"""
        pass

    def GetY(self):
        """"""
        pass

    def SetSashPosition(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class SysColourChangedEvent(Event):
    """"""

    def __init__(self):
        """"""
        pass


class TextUrlEvent(CommandEvent):
    """"""

    def GetMouseEvent(self):
        """"""
        pass

    def GetURLEnd(self):
        """"""
        pass

    def GetURLStart(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class TimerEvent(Event):
    """"""

    def GetInterval(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class TreeEvent(NotifyEvent):
    """"""

    def GetCode(self):
        """"""
        pass

    def GetItem(self):
        """"""
        pass

    def GetKeyCode(self):
        """"""
        pass

    def GetKeyEvent(self):
        """"""
        pass

    def GetLabel(self):
        """"""
        pass

    def GetOldItem(self):
        """"""
        pass

    def GetPoint(self):
        """"""
        pass

    def IsEditCancelled(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class UpdateUIEvent(Event):
    """"""

    def Check(self):
        """"""
        pass

    def Enable(self):
        """"""
        pass

    def GetChecked(self):
        """"""
        pass

    def GetEnabled(self):
        """"""
        pass

    def GetSetChecked(self):
        """"""
        pass

    def GetSetEnabled(self):
        """"""
        pass

    def GetSetText(self):
        """"""
        pass

    def GetText(self):
        """"""
        pass

    def SetText(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class WindowCreateEvent(CommandEvent):
    """"""

    def GetWindow(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class WindowDestroyEvent(CommandEvent):
    """"""

    def GetWindow(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass



#----------------------------------------------------------------------
# Name:         popup
# Purpose:      Generic popup control
#
# Author:       Gerrit van Dyk
#
# Created:      2002/11/20
# Version:      0.1
# RCS-ID:       $Id: popupctl.py,v 1.1.2.3 2003/02/26 18:38:14 RD Exp $
# License:      wxWindows license
#----------------------------------------------------------------------

from wxPython.wx import *
from wxPython.lib.buttons import wxGenButtonEvent


class PopButton(wxPyControl):
    def __init__(self,*_args,**_kwargs):
        apply(wxPyControl.__init__,(self,) + _args,_kwargs)

        self.up = True
        self.didDown = False

        self.InitColours()

        EVT_LEFT_DOWN(self,             self.OnLeftDown)
        EVT_LEFT_UP(self,               self.OnLeftUp)
        EVT_MOTION(self,                self.OnMotion)
        EVT_PAINT(self,                 self.OnPaint)

    def InitColours(self):
        faceClr      = wxSystemSettings_GetSystemColour(wxSYS_COLOUR_BTNFACE)
        self.faceDnClr = faceClr
        self.SetBackgroundColour(faceClr)

        shadowClr    = wxSystemSettings_GetSystemColour(wxSYS_COLOUR_BTNSHADOW)
        highlightClr = wxSystemSettings_GetSystemColour(wxSYS_COLOUR_BTNHIGHLIGHT)
        self.shadowPen    = wxPen(shadowClr, 1, wxSOLID)
        self.highlightPen = wxPen(highlightClr, 1, wxSOLID)
        self.blackPen     = wxPen(wxBLACK, 1, wxSOLID)

    def Notify(self):
        evt = wxGenButtonEvent(wxEVT_COMMAND_BUTTON_CLICKED, self.GetId())
        evt.SetIsDown(not self.up)
        evt.SetButtonObj(self)
        evt.SetEventObject(self)
        self.GetEventHandler().ProcessEvent(evt)

    def OnEraseBackground(self, event):
        pass

    def OnLeftDown(self, event):
        if not self.IsEnabled():
            return
        self.didDown = True
        self.up = False
        self.CaptureMouse()
        self.GetParent().textCtrl.SetFocus()
        self.Refresh()
        event.Skip()

    def OnLeftUp(self, event):
        if not self.IsEnabled():
            return
        if self.didDown:
            self.ReleaseMouse()
            if not self.up:
                self.Notify()
            self.up = True
            self.Refresh()
            self.didDown = False
        event.Skip()

    def OnMotion(self, event):
        if not self.IsEnabled():
            return
        if event.LeftIsDown():
            if self.didDown:
                x,y = event.GetPositionTuple()
                w,h = self.GetClientSizeTuple()
                if self.up and x<w and x>=0 and y<h and y>=0:
                    self.up = False
                    self.Refresh()
                    return
                if not self.up and (x<0 or y<0 or x>=w or y>=h):
                    self.up = True
                    self.Refresh()
                    return
        event.Skip()

    def DrawBezel(self, dc, x1, y1, x2, y2):
        # draw the upper left sides
        if self.up:
            dc.SetPen(self.highlightPen)
        else:
            dc.SetPen(self.shadowPen)
        for i in range(2):
            dc.DrawLine(x1+i, y1, x1+i, y2-i)
            dc.DrawLine(x1, y1+i, x2-i, y1+i)

        # draw the lower right sides
        if self.up:
            dc.SetPen(self.shadowPen)
        else:
            dc.SetPen(self.highlightPen)
        for i in range(2):
            dc.DrawLine(x1+i, y2-i, x2+1, y2-i)
            dc.DrawLine(x2-i, y1+i, x2-i, y2)

    def DrawArrow(self,dc):
        size = self.GetSize()
        mx = size.x / 2
        my = size.y / 2
        dc.SetPen(self.highlightPen)
        dc.DrawLine(mx-5,my-5,mx+5,my-5)
        dc.DrawLine(mx-5,my-5,mx,my+5)
        dc.SetPen(self.shadowPen)
        dc.DrawLine(mx+4,my-5,mx,my+5)
        dc.SetPen(self.blackPen)
        dc.DrawLine(mx+5,my-5,mx,my+5)

    def OnPaint(self, event):
        width, height = self.GetClientSizeTuple()
        x1 = y1 = 0
        x2 = width - 1
        y2 = height - 1
        dc = wxBufferedPaintDC(self)
        if self.up:
            dc.SetBackground(wxBrush(self.GetBackgroundColour(), wxSOLID))
        else:
            dc.SetBackground(wxBrush(self.faceDnClr, wxSOLID))
        dc.Clear()
        self.DrawBezel(dc, x1, y1, x2, y2)
        self.DrawArrow(dc)


#---------------------------------------------------------------------------


# Tried to use wxPopupWindow but the control misbehaves on MSW
class wxPopupDialog(wxDialog):
    def __init__(self,parent,content = None):
        wxDialog.__init__(self,parent,-1,'', style = wxSTAY_ON_TOP)

        self.ctrl = parent
        self.win = wxWindow(self,-1,pos = wxPoint(0,0),style = 0)

        if content:
            self.SetContent(content)

    def SetContent(self,content):
        self.content = content
        self.content.Reparent(self.win)
        self.content.Show(True)
        self.win.SetClientSize(self.content.GetSize())
        self.SetSize(self.win.GetSize())

    def Display(self):
        pos = self.ctrl.ClientToScreen( (0,0) )
        dSize = wxGetDisplaySize()
        selfSize = self.GetSize()
        tcSize = self.ctrl.GetSize()

        pos.x -= (selfSize.x - tcSize.x) / 2
        if pos.x + selfSize.x > dSize.x:
            pos.x = dSize.x - selfSize.x
        if pos.x < 0:
            pos.x = 0

        pos.y += tcSize.height
        if pos.y + selfSize.y > dSize.y:
            pos.y = dSize.y - selfSize.y
        if pos.y < 0:
            pos.y = 0

        self.MoveXY(pos.x,pos.y)

        self.ctrl.FormatContent()

        self.ShowModal()


#---------------------------------------------------------------------------


class wxPopupControl(wxPyControl):
    def __init__(self,*_args,**_kwargs):
        if _kwargs.has_key('value'):
            del _kwargs['value']
        apply(wxPyControl.__init__,(self,) + _args,_kwargs)

        self.textCtrl = wxTextCtrl(self,-1,'',pos = wxPoint(0,0))
        self.bCtrl = PopButton(self,-1)
        self.pop = None
        self.content = None
        self.OnSize(None)

        EVT_SIZE(self,self.OnSize)
        EVT_BUTTON(self.bCtrl,self.bCtrl.GetId(),self.OnButton)

    def OnSize(self,evt):
        w,h = self.GetClientSizeTuple()
        self.textCtrl.SetDimensions(0,0,w-17,h)
        self.bCtrl.SetDimensions(w-17,0,17,h)

    def OnButton(self,evt):
        if not self.pop:
            if self.content:
                self.pop = wxPopupDialog(self,self.content)
                del self.content
            else:
                print 'No Content to pop'
        if self.pop:
            self.pop.Display()

    def Enable(self,flag):
        wxPyControl.Enable(self,flag)
        self.textCtrl.Enable(flag)
        self.bCtrl.Enable(flag)

    def SetPopupContent(self,content):
        if not self.pop:
            self.content = content
            self.content.Show(False)
        else:
            self.pop.SetContent(content)

    def FormatContent(self):
        pass

    def PopDown(self):
        if self.pop:
            self.pop.EndModal(1)

    def SetValue(self,value):
        self.textCtrl.SetValue(value)

    def GetValue(self):
        return self.textCtrl.GetValue()


# an alias
wxPopupCtrl = wxPopupControl



# This file was created automatically by SWIG.
import gizmosc

from misc import *

from misc2 import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

from mdi import *

from frames import *

from stattool import *

from controls import *

from controls2 import *

from windows2 import *

from cmndlgs import *

from windows3 import *

from image import *

from printfw import *

from sizers import *

from filesys import *

def EVT_DYNAMIC_SASH_SPLIT(win, id, func):
    win.Connect(id, -1, wxEVT_DYNAMIC_SASH_SPLIT, func)

def EVT_DYNAMIC_SASH_UNIFY(win, id, func):
    win.Connect(id, -1, wxEVT_DYNAMIC_SASH_UNIFY, func)

class wxDynamicSashSplitEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxDynamicSashSplitEvent instance at %s>" % (self.this,)
class wxDynamicSashSplitEvent(wxDynamicSashSplitEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gizmosc.new_wxDynamicSashSplitEvent,_args,_kwargs)
        self.thisown = 1




class wxDynamicSashUnifyEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxDynamicSashUnifyEvent instance at %s>" % (self.this,)
class wxDynamicSashUnifyEvent(wxDynamicSashUnifyEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gizmosc.new_wxDynamicSashUnifyEvent,_args,_kwargs)
        self.thisown = 1




class wxDynamicSashWindowPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(gizmosc.wxDynamicSashWindow_Create,(self,) + _args, _kwargs)
        return val
    def GetHScrollBar(self, *_args, **_kwargs):
        val = apply(gizmosc.wxDynamicSashWindow_GetHScrollBar,(self,) + _args, _kwargs)
        if val: val = wxScrollBarPtr(val) 
        return val
    def GetVScrollBar(self, *_args, **_kwargs):
        val = apply(gizmosc.wxDynamicSashWindow_GetVScrollBar,(self,) + _args, _kwargs)
        if val: val = wxScrollBarPtr(val) 
        return val
    def __repr__(self):
        return "<C wxDynamicSashWindow instance at %s>" % (self.this,)
class wxDynamicSashWindow(wxDynamicSashWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gizmosc.new_wxDynamicSashWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreDynamicSashWindow(*_args,**_kwargs):
    val = wxDynamicSashWindowPtr(apply(gizmosc.new_wxPreDynamicSashWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxEditableListBoxPtr(wxPanelPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetStrings(self, *_args, **_kwargs):
        val = apply(gizmosc.wxEditableListBox_SetStrings,(self,) + _args, _kwargs)
        return val
    def GetStrings(self, *_args, **_kwargs):
        val = apply(gizmosc.wxEditableListBox_GetStrings,(self,) + _args, _kwargs)
        return val
    def GetListCtrl(self, *_args, **_kwargs):
        val = apply(gizmosc.wxEditableListBox_GetListCtrl,(self,) + _args, _kwargs)
        return val
    def GetDelButton(self, *_args, **_kwargs):
        val = apply(gizmosc.wxEditableListBox_GetDelButton,(self,) + _args, _kwargs)
        return val
    def GetNewButton(self, *_args, **_kwargs):
        val = apply(gizmosc.wxEditableListBox_GetNewButton,(self,) + _args, _kwargs)
        return val
    def GetUpButton(self, *_args, **_kwargs):
        val = apply(gizmosc.wxEditableListBox_GetUpButton,(self,) + _args, _kwargs)
        return val
    def GetDownButton(self, *_args, **_kwargs):
        val = apply(gizmosc.wxEditableListBox_GetDownButton,(self,) + _args, _kwargs)
        return val
    def GetEditButton(self, *_args, **_kwargs):
        val = apply(gizmosc.wxEditableListBox_GetEditButton,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxEditableListBox instance at %s>" % (self.this,)
class wxEditableListBox(wxEditableListBoxPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gizmosc.new_wxEditableListBox,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxRemotelyScrolledTreeCtrlPtr(wxTreeCtrlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def HideVScrollbar(self, *_args, **_kwargs):
        val = apply(gizmosc.wxRemotelyScrolledTreeCtrl_HideVScrollbar,(self,) + _args, _kwargs)
        return val
    def AdjustRemoteScrollbars(self, *_args, **_kwargs):
        val = apply(gizmosc.wxRemotelyScrolledTreeCtrl_AdjustRemoteScrollbars,(self,) + _args, _kwargs)
        return val
    def GetScrolledWindow(self, *_args, **_kwargs):
        val = apply(gizmosc.wxRemotelyScrolledTreeCtrl_GetScrolledWindow,(self,) + _args, _kwargs)
        if val: val = wxScrolledWindowPtr(val) 
        return val
    def ScrollToLine(self, *_args, **_kwargs):
        val = apply(gizmosc.wxRemotelyScrolledTreeCtrl_ScrollToLine,(self,) + _args, _kwargs)
        return val
    def SetCompanionWindow(self, *_args, **_kwargs):
        val = apply(gizmosc.wxRemotelyScrolledTreeCtrl_SetCompanionWindow,(self,) + _args, _kwargs)
        return val
    def GetCompanionWindow(self, *_args, **_kwargs):
        val = apply(gizmosc.wxRemotelyScrolledTreeCtrl_GetCompanionWindow,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxRemotelyScrolledTreeCtrl instance at %s>" % (self.this,)
class wxRemotelyScrolledTreeCtrl(wxRemotelyScrolledTreeCtrlPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gizmosc.new_wxRemotelyScrolledTreeCtrl,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxTreeCompanionWindowPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(gizmosc.wxTreeCompanionWindow__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def GetTreeCtrl(self, *_args, **_kwargs):
        val = apply(gizmosc.wxTreeCompanionWindow_GetTreeCtrl,(self,) + _args, _kwargs)
        if val: val = wxRemotelyScrolledTreeCtrlPtr(val) 
        return val
    def SetTreeCtrl(self, *_args, **_kwargs):
        val = apply(gizmosc.wxTreeCompanionWindow_SetTreeCtrl,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTreeCompanionWindow instance at %s>" % (self.this,)
class wxTreeCompanionWindow(wxTreeCompanionWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gizmosc.new_wxTreeCompanionWindow,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxTreeCompanionWindow)
        self._setOORInfo(self)




class wxThinSplitterWindowPtr(wxSplitterWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxThinSplitterWindow instance at %s>" % (self.this,)
class wxThinSplitterWindow(wxThinSplitterWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gizmosc.new_wxThinSplitterWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxSplitterScrolledWindowPtr(wxScrolledWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __repr__(self):
        return "<C wxSplitterScrolledWindow instance at %s>" % (self.this,)
class wxSplitterScrolledWindow(wxSplitterScrolledWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gizmosc.new_wxSplitterScrolledWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxLEDNumberCtrlPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(gizmosc.wxLEDNumberCtrl_Create,(self,) + _args, _kwargs)
        return val
    def GetAlignment(self, *_args, **_kwargs):
        val = apply(gizmosc.wxLEDNumberCtrl_GetAlignment,(self,) + _args, _kwargs)
        return val
    def GetDrawFaded(self, *_args, **_kwargs):
        val = apply(gizmosc.wxLEDNumberCtrl_GetDrawFaded,(self,) + _args, _kwargs)
        return val
    def GetValue(self, *_args, **_kwargs):
        val = apply(gizmosc.wxLEDNumberCtrl_GetValue,(self,) + _args, _kwargs)
        return val
    def SetAlignment(self, *_args, **_kwargs):
        val = apply(gizmosc.wxLEDNumberCtrl_SetAlignment,(self,) + _args, _kwargs)
        return val
    def SetDrawFaded(self, *_args, **_kwargs):
        val = apply(gizmosc.wxLEDNumberCtrl_SetDrawFaded,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(gizmosc.wxLEDNumberCtrl_SetValue,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxLEDNumberCtrl instance at %s>" % (self.this,)
class wxLEDNumberCtrl(wxLEDNumberCtrlPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(gizmosc.new_wxLEDNumberCtrl,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreLEDNumberCtrl(*_args,**_kwargs):
    val = wxLEDNumberCtrlPtr(apply(gizmosc.new_wxPreLEDNumberCtrl,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val




#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------

wxEVT_DYNAMIC_SASH_SPLIT = gizmosc.wxEVT_DYNAMIC_SASH_SPLIT
wxEVT_DYNAMIC_SASH_UNIFY = gizmosc.wxEVT_DYNAMIC_SASH_UNIFY
wxDS_MANAGE_SCROLLBARS = gizmosc.wxDS_MANAGE_SCROLLBARS
wxDS_DRAG_CORNER = gizmosc.wxDS_DRAG_CORNER
wxEL_ALLOW_NEW = gizmosc.wxEL_ALLOW_NEW
wxEL_ALLOW_EDIT = gizmosc.wxEL_ALLOW_EDIT
wxEL_ALLOW_DELETE = gizmosc.wxEL_ALLOW_DELETE
wxLED_ALIGN_LEFT = gizmosc.wxLED_ALIGN_LEFT
wxLED_ALIGN_RIGHT = gizmosc.wxLED_ALIGN_RIGHT
wxLED_ALIGN_CENTER = gizmosc.wxLED_ALIGN_CENTER
wxLED_ALIGN_MASK = gizmosc.wxLED_ALIGN_MASK
wxLED_DRAW_FADED = gizmosc.wxLED_DRAW_FADED


#-------------- USER INCLUDE -----------------------

# Stuff these names into the wx namespace so wxPyConstructObject can find them

wx.wxDynamicSashSplitEventPtr       = wxDynamicSashSplitEventPtr
wx.wxDynamicSashUnifyEventPtr       = wxDynamicSashUnifyEventPtr
wx.wxDynamicSashWindowPtr           = wxDynamicSashWindowPtr

wx.wxEditableListBoxPtr             = wxEditableListBoxPtr

wx.wxRemotelyScrolledTreeCtrlPtr    = wxRemotelyScrolledTreeCtrlPtr
wx.wxTreeCompanionWindowPtr         = wxTreeCompanionWindowPtr
wx.wxThinSplitterWindowPtr          = wxThinSplitterWindowPtr
wx.wxSplitterScrolledWindowPtr      = wxSplitterScrolledWindowPtr
